#!/usr/bin/env python

import extListview, gobject, gtk, gtk.gdk

def onListModified():
    print 'Modified!'

def onColumnVisibilityChanged(list, colTitle, visible):
    print 'Visibility of', colTitle, 'is now', visible

# Setup the main window
window = gtk.Window(gtk.WINDOW_TOPLEVEL)
window.connect('delete_event', gtk.main_quit)
window.set_default_size(450, 300)

# Setup the scrolled window
scrolledwin = gtk.ScrolledWindow()
scrolledwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
box = gtk.VBox()
window.add(box)
box.pack_start(scrolledwin)
box.set_homogeneous(False)

# Create the two renderers used in the listview
txtRdr    = gtk.CellRendererText()
pixbufRdr = gtk.CellRendererPixbuf()

# The fields in a row of the listview
(
    ROW_ICO,   # Icon drawn in front of the row
    ROW_NUM,   # Track number
    ROW_TIT,   # Track title
    ROW_ART,   # Track artist
    ROW_ALB,   # Track album
    ROW_GNR,   # Track genre
    ROW_EXT    # Some extra information
) = range(7)

# Setup the columns
#  Part 1 is the title of the column. If None, the column is not visible at all.
#  Part 2 is a list of tuple (CellRenderer, ValueType) to be put in that column.
#  Part 3 is the tuple with all the fields used when sorting on that column: first sort on the first field, then on the second...
#  Part 4 is a boolean that specifies whether the column is expanded.
#  Part 5 is a boolean giving the initial visibility of the column. This can be changed by the user by right-clicking on the column headers.
columns = (('#',      [(pixbufRdr, gtk.gdk.Pixbuf), (txtRdr, gobject.TYPE_INT)], (ROW_NUM, ROW_TIT),                            False, True),
           ('Title',  [(txtRdr, gobject.TYPE_STRING)],                           (ROW_TIT,),                                    True,  True),
           ('Artist', [(txtRdr, gobject.TYPE_STRING)],                           (ROW_ART, ROW_ALB, ROW_NUM, ROW_TIT),          True,  True),
           ('Album',  [(txtRdr, gobject.TYPE_STRING)],                           (ROW_ALB, ROW_NUM, ROW_TIT),                   True,  True),
           ('Genre',  [(txtRdr, gobject.TYPE_STRING)],                           (ROW_GNR, ROW_ART, ROW_ALB, ROW_NUM, ROW_TIT), True,  False),
           (None,     [(None, gobject.TYPE_STRING)],                             (None,),                                       False, False))

listview = extListview.ExtListView(columns, sortable=True, useMarkup=False, canShowHideColumns=True)
listview.enableDNDReordering()
listview.connect('extlistview-modified', lambda *args: onListModified())
listview.connect('extlistview-column-visibility-changed', onColumnVisibilityChanged)
scrolledwin.add(listview)

# Buttons
buttons = gtk.HButtonBox()
box.pack_start(buttons, False)

shuffleBtn = gtk.Button('Shuffle')
shuffleBtn.connect('clicked', lambda btn: listview.shuffle())
buttons.add(shuffleBtn)

# Some arbitrary data to put in the listview
icon = listview.render_icon(gtk.STOCK_MEDIA_PLAY, gtk.ICON_SIZE_MENU)

rows = [
            [None, 1, 'Final Impact', 'Front Line Assembly', 'Tactical Neural Implant', 'Electro-Indus', 'Something interesting 1'],
            [None, 2, 'The Blade',    'Front Line Assembly', 'Tactical Neural Implant', 'Electro-Indus', 'Something interesting 2'],
            [None, 3, 'Mindphaser',   'Front Line Assembly', 'Tactical Neural Implant', 'Electro-Indus', 'Something interesting 3'],
            [None, 4, 'Remorse',      'Front Line Assembly', 'Tactical Neural Implant', 'Electro-Indus', 'Something interesting 4'],
            [None, 1, 'Retribution',  'Front Line Assembly', 'Implode',                 'Electro-Indus', 'Something interesting 5'],
            [icon, 2, 'Fatalist',     'Front Line Assembly', 'Implode',                 'Electro-Indus', 'Something interesting 6'],
            [None, 3, 'Prophecy',     'Front Line Assembly', 'Implode',                 'Electro-Indus', 'Something interesting 7']
       ]

listview.insertRows(rows)

# Let's go
window.show_all()
gtk.main()
